@@ -8,11 +8,18 @@ import click
 from phcontext.phcontextfacade import PhContextFacade
 
 
-@click.command()
+@click.group()
+def phcli():
+    pass
+
+
+@phcli.command()
 @click.option("--cmd", prompt="Your command is", help="The command that you want to process.",
               type=click.Choice(["create", "combine", "dag", "publish", "run", "submit", "status"]))
-@click.option("--path", prompt="Your config and python job file directory", help="The concert job you want the process.")
-def ph_command(cmd, path):
+@click.option("-p", "--path", prompt="Your config and python job file directory",
+              help="The concert job you want the process.")
+@click.option("-c", "--context", default="")
+def maxauto(cmd, path, context):
     """The Pharbers Max Job Command Line Interface (CLI)
 
         --cmd Args: \n
@@ -23,5 +30,5 @@ def ph_command(cmd, path):
         --path Args: \n
             the dictionary that specify the py and yaml file
     """
-    context = PhContextFacade(cmd, path)
-    return context.execute()
+    facade = PhContextFacade(cmd, path, context)
+    click.get_current_context().exit(facade.execute())
