@@ -260,7 +260,7 @@ class PhContextFacade(object):
         phlogger.info("submit command with context " + self.context)
         udags = {}
         if self.context is not "":
-            udags = ast.literal_eval(self.context)
+            udags = ast.literal_eval(self.context.replace(" ", ""))
         phlogger.info(udags)
         submit_prefix = "s3a://s3fs-ph-storage/airflow/dags/phjobs/" + self.path + "/"
         args = s3.get_object_lines("s3fs-ph-storage", "airflow/dags/phjobs/" + self.path + "/args.properties")
